@@ -1,6 +1,8 @@
 #ifndef _INTERFACES_H_
 #define _INTERFACES_H_
 
+#define TO_STRING(x) #x
+
 //Gecko Embedding API
 #include <nsEmbedAPI.h>
 
@@ -125,6 +127,23 @@
 #endif
 
 #define NS_FROZENCALL
+#define XRE_API(type, name, params) \
+  typedef type (NS_FROZENCALL * name##Type) params; \
+  extern name##Type name NS_HIDDEN;
+
+XRE_API(nsresult,
+	XRE_InitEmbedding, (nsILocalFile *aLibXULDirectory,
+						nsILocalFile *aAppDirectory,
+						nsIDirectoryServiceProvider *aAppDirProvider,
+						nsStaticModuleInfo const *aStaticComponents,
+						PRUint32 aStaticComponentCount))
+
+XRE_API(void, XRE_TermEmbedding, ())
+
+XRE_API(PRBool,
+		GRE_GetCurrentProcessDirectory,
+		(char* buffer))
+
 
 #ifdef NS_UNIX
 #include <gtk/gtk.h>
